@@ -52,5 +52,20 @@ class ConfigurationManager:
 
         return os.getenv(ENV_JOB_KEY, None)
 
+    @property
+    def has_legacy_eval_folder(self) -> bool:
+        from uipath._utils.constants import LEGACY_EVAL_FOLDER
+
+        eval_path = Path(os.getcwd()) / LEGACY_EVAL_FOLDER
+        return eval_path.exists() and eval_path.is_dir()
+
+    # TODO: to be renamed to "evaluations"
+    @property
+    def has_eval_folder(self) -> bool:
+        from uipath._utils.constants import EVALS_FOLDER
+
+        coded_eval_path = Path(os.getcwd()) / EVALS_FOLDER
+        return coded_eval_path.exists() and coded_eval_path.is_dir()
+
 
 UiPathConfig = ConfigurationManager()
