@@ -5,7 +5,9 @@ from .attachments_service import AttachmentsService
 from .buckets_service import BucketsService
 from .connections_service import ConnectionsService
 from .context_grounding_service import ContextGroundingService
+from .documents_service import DocumentsService
 from .entities_service import EntitiesService
+from .external_application_service import ExternalApplicationService
 from .folder_service import FolderService
 from .jobs_service import JobsService
 from .llm_gateway_service import UiPathLlmChatService, UiPathOpenAIService
@@ -19,6 +21,7 @@ __all__ = [
     "BucketsService",
     "ConnectionsService",
     "ContextGroundingService",
+    "DocumentsService",
     "ProcessesService",
     "ApiClient",
     "QueuesService",
@@ -27,4 +30,5 @@ __all__ = [
     "UiPathLlmChatService",
     "FolderService",
     "EntitiesService",
+    "ExternalApplicationService",
 ]
