@@ -12,7 +12,7 @@ from .._folder_context import FolderContext
 from .._utils import Endpoint, RequestSpec, header_folder, resource_override
 from .._utils._ssl_context import get_httpx_client_kwargs
 from ..models import Bucket, BucketFile
-from ..tracing._traced import traced
+from ..tracing import traced
 from ._base_service import BaseService
 
 
