@@ -63,12 +63,15 @@ def _simple_serialize_defaults(obj):
 
 @dataclass
 class UiPathSpan:
-    """Represents a span in the UiPath tracing system."""
+    """Represents a span in the UiPath tracing system.
+
+    Note: attributes can be either a JSON string (backwards compatible) or a dict (optimized).
+    """
 
     id: uuid.UUID
     trace_id: uuid.UUID
     name: str
-    attributes: str
+    attributes: str | Dict[str, Any]  # Support both str (legacy) and dict (optimized)
     parent_id: Optional[uuid.UUID] = None
     start_time: str = field(default_factory=lambda: datetime.now().isoformat())
     end_time: str = field(default_factory=lambda: datetime.now().isoformat())
@@ -96,16 +99,32 @@ class UiPathSpan:
 
     job_key: Optional[str] = field(default_factory=lambda: env.get("UIPATH_JOB_KEY"))
 
-    def to_dict(self) -> Dict[str, Any]:
-        """Convert the Span to a dictionary suitable for JSON serialization."""
+    def to_dict(self, serialize_attributes: bool = True) -> Dict[str, Any]:
+        """Convert the Span to a dictionary suitable for JSON serialization.
+
+        Args:
+            serialize_attributes: If True and attributes is a dict, serialize to JSON string.
+                                 If False, keep attributes as-is (dict or str).
+                                 Default True for backwards compatibility.
+        """
+        # Cache UUID string conversions to avoid repeated str() calls
+        id_str = str(self.id)
+        trace_id_str = str(self.trace_id)
+        parent_id_str = str(self.parent_id) if self.parent_id else None
+
+        # Handle attributes serialization
+        attributes_out = self.attributes
+        if serialize_attributes and isinstance(self.attributes, dict):
+            attributes_out = json.dumps(self.attributes)
+
         return {
-            "Id": str(self.id),
-            "TraceId": str(self.trace_id),
-            "ParentId": str(self.parent_id) if self.parent_id else None,
+            "Id": id_str,
+            "TraceId": trace_id_str,
+            "ParentId": parent_id_str,
             "Name": self.name,
             "StartTime": self.start_time,
             "EndTime": self.end_time,
-            "Attributes": self.attributes,
+            "Attributes": attributes_out,
             "Status": self.status,
             "CreatedAt": self.created_at,
             "UpdatedAt": self.updated_at,
@@ -168,9 +187,18 @@ class _SpanUtils:
 
     @staticmethod
     def otel_span_to_uipath_span(
-        otel_span: ReadableSpan, custom_trace_id: Optional[str] = None
+        otel_span: ReadableSpan,
+        custom_trace_id: Optional[str] = None,
+        serialize_attributes: bool = True,
     ) -> UiPathSpan:
-        """Convert an OpenTelemetry span to a UiPathSpan."""
+        """Convert an OpenTelemetry span to a UiPathSpan.
+
+        Args:
+            otel_span: The OpenTelemetry span to convert
+            custom_trace_id: Optional custom trace ID to use
+            serialize_attributes: If True, serialize attributes to JSON string (backwards compatible).
+                                 If False, keep as dict for optimized processing. Default True.
+        """
         # Extract the context information from the OTel span
         span_context = otel_span.get_span_context()
 
@@ -192,10 +220,11 @@ class _SpanUtils:
         if parent_span_id_str:
             parent_id = uuid.UUID(parent_span_id_str)
 
-        # Convert attributes to a format compatible with UiPathSpan
-        attributes_dict: dict[str, Any] = (
-            dict(otel_span.attributes) if otel_span.attributes else {}
-        )
+        # Build attributes dict efficiently
+        # Use the otel attributes as base - we only add new keys, don't modify existing
+        otel_attrs = otel_span.attributes if otel_span.attributes else {}
+        # Only copy if we need to modify - we'll build attributes_dict lazily
+        attributes_dict: dict[str, Any] = dict(otel_attrs) if otel_attrs else {}
 
         # Map status
         status = 1  # Default to OK
@@ -203,32 +232,31 @@ class _SpanUtils:
             status = 2  # Error
             attributes_dict["error"] = otel_span.status.description
 
-        original_inputs = attributes_dict.get("input", None)
-        original_outputs = attributes_dict.get("output", None)
-
+        # Process inputs - avoid redundant parsing if already parsed
+        original_inputs = otel_attrs.get("input", None)
         if original_inputs:
-            try:
-                if isinstance(original_inputs, str):
-                    json_inputs = json.loads(original_inputs)
-                    attributes_dict["input.value"] = json_inputs
+            if isinstance(original_inputs, str):
+                try:
+                    attributes_dict["input.value"] = json.loads(original_inputs)
                     attributes_dict["input.mime_type"] = "application/json"
-                else:
+                except Exception as e:
+                    logger.warning(f"Error parsing inputs: {e}")
                     attributes_dict["input.value"] = original_inputs
-            except Exception as e:
-                logger.warning(f"Error parsing inputs: {e}")
-                attributes_dict["input.value"] = str(original_inputs)
+            else:
+                attributes_dict["input.value"] = original_inputs
 
+        # Process outputs - avoid redundant parsing if already parsed
+        original_outputs = otel_attrs.get("output", None)
         if original_outputs:
-            try:
-                if isinstance(original_outputs, str):
-                    json_outputs = json.loads(original_outputs)
-                    attributes_dict["output.value"] = json_outputs
+            if isinstance(original_outputs, str):
+                try:
+                    attributes_dict["output.value"] = json.loads(original_outputs)
                     attributes_dict["output.mime_type"] = "application/json"
-                else:
+                except Exception as e:
+                    logger.warning(f"Error parsing output: {e}")
                     attributes_dict["output.value"] = original_outputs
-            except Exception as e:
-                logger.warning(f"Error parsing output: {e}")
-                attributes_dict["output.value"] = str(original_outputs)
+            else:
+                attributes_dict["output.value"] = original_outputs
 
         # Add events as additional attributes if they exist
         if otel_span.events:
@@ -275,7 +303,9 @@ class _SpanUtils:
             trace_id=trace_id,
             parent_id=parent_id,
             name=otel_span.name,
-            attributes=json.dumps(attributes_dict),
+            attributes=json.dumps(attributes_dict)
+            if serialize_attributes
+            else attributes_dict,
             start_time=start_time,
             end_time=end_time_str,
             status=status,
@@ -334,34 +364,12 @@ class _SpanUtils:
             )
             return {"args": args, "kwargs": kwargs}
 
-    @staticmethod
-    def _has_ancestor_with_name(
-        span: ReadableSpan, ancestor_name: str, span_map: Dict[int, ReadableSpan]
-    ) -> bool:
-        """Check if this span or any of its ancestors has a given name."""
-        if span.name == ancestor_name:
-            return True
-
-        current = span
-        while current.parent is not None:
-            parent_span = span_map.get(current.parent.span_id)
-            if parent_span is None:
-                break
-            if parent_span.name == ancestor_name:
-                return True
-            current = parent_span
-
-        return False
-
     @staticmethod
     def spans_to_llm_context(spans: list[ReadableSpan]) -> str:
         """Convert spans to a formatted conversation history string suitable for LLM context.
 
         Includes function calls (including LLM calls) with their inputs and outputs.
         """
-        # Build span_id -> span map for parent chain traversal
-        span_map = {span.get_span_context().span_id: span for span in spans}
-
         history = []
         for span in spans:
             attributes = dict(span.attributes) if span.attributes else {}
@@ -372,10 +380,6 @@ class _SpanUtils:
             if not input_value or not output_value:
                 continue
 
-            # Skip spans that are internal LLM calls (eg. for tool mocking in evals)
-            if _SpanUtils._has_ancestor_with_name(span, "__mocker__", span_map):
-                continue
-
             history.append(f"Function: {span.name}")
             history.append(f"Input: {input_value}")
             history.append(f"Output: {output_value}")
