@@ -23,12 +23,6 @@ class UiPathEndpoints(Enum):
     OR_EMBEDDING_ENDPOINT = "orchestrator_/llm/openai/deployments/{model}/embeddings?api-version={api_version}"
     OR_CAPABILITIES_ENDPOINT = "orchestrator_/llm/api/capabilities"
 
-    LG_NORMALIZED_COMPLETION_ENDPOINT = "llmgateway_/api/chat/completions"
-    LG_PASSTHROUGH_COMPLETION_ENDPOINT = "llmgateway_/openai/deployments/{model}/chat/completions?api-version={api_version}"
-    LG_EMBEDDING_ENDPOINT = (
-        "llmgateway_/openai/deployments/{model}/embeddings?api-version={api_version}"
-    )
-
 
 class EndpointManager:
     """Manages and caches the UiPath endpoints.
@@ -39,13 +33,11 @@ class EndpointManager:
     The endpoint selection follows a fallback order:
     1. AgentHub (if available)
     2. Orchestrator (if available)
-    3. LLMGateway (default fallback)
 
     Environment Variable Override:
     The fallback behavior can be bypassed using the UIPATH_LLM_SERVICE environment variable:
     - 'agenthub' or 'ah': Force use of AgentHub endpoints (skips capability checks)
     - 'orchestrator' or 'or': Force use of Orchestrator endpoints (skips capability checks)
-    - 'llmgateway' or 'gateway': Force use of LLMGateway endpoints (skips capability checks)
 
     Class Attributes:
         _base_url (str): The base URL for UiPath services, retrieved from the UIPATH_URL
@@ -133,9 +125,7 @@ class EndpointManager:
         )
 
     @classmethod
-    def _select_endpoint(
-        cls, ah: UiPathEndpoints, orc: UiPathEndpoints, gw: UiPathEndpoints
-    ) -> str:
+    def _select_endpoint(cls, ah: UiPathEndpoints, orc: UiPathEndpoints) -> str:
         """Select an endpoint based on UIPATH_LLM_SERVICE override or capability checks."""
         service_override = os.getenv("UIPATH_LLM_SERVICE", "").lower()
 
@@ -143,8 +133,6 @@ class EndpointManager:
             return ah.value
         if service_override in ("orchestrator", "or"):
             return orc.value
-        if service_override in ("llmgateway", "gateway"):
-            return gw.value
 
         # Determine fallback order based on environment hints
         hdens_env = os.getenv("HDENS_ENV", "").lower()
@@ -165,8 +153,11 @@ class EndpointManager:
             if is_available():
                 return endpoint.value
 
-        # Final fallback to LLMGateway
-        return gw.value
+        url = os.getenv("UIPATH_URL", "")
+        if ".uipath.com" in url:
+            return ah.value
+        else:
+            return orc.value
 
     @classmethod
     def get_passthrough_endpoint(cls) -> str:
@@ -174,7 +165,6 @@ class EndpointManager:
         return cls._select_endpoint(
             UiPathEndpoints.AH_PASSTHROUGH_COMPLETION_ENDPOINT,
             UiPathEndpoints.OR_PASSTHROUGH_COMPLETION_ENDPOINT,
-            UiPathEndpoints.LG_PASSTHROUGH_COMPLETION_ENDPOINT,
         )
 
     @classmethod
@@ -183,7 +173,6 @@ class EndpointManager:
         return cls._select_endpoint(
             UiPathEndpoints.AH_NORMALIZED_COMPLETION_ENDPOINT,
             UiPathEndpoints.OR_NORMALIZED_COMPLETION_ENDPOINT,
-            UiPathEndpoints.LG_NORMALIZED_COMPLETION_ENDPOINT,
         )
 
     @classmethod
@@ -192,5 +181,4 @@ class EndpointManager:
         return cls._select_endpoint(
             UiPathEndpoints.AH_EMBEDDING_ENDPOINT,
             UiPathEndpoints.OR_EMBEDDING_ENDPOINT,
-            UiPathEndpoints.LG_EMBEDDING_ENDPOINT,
         )
