@@ -148,39 +148,32 @@ class TestPush:
         mock_structure = {
             "id": "root",
             "name": "root",
-            "folders": [
-                {
-                    "id": "414af585-7e88-4774-ad94-cf6bd48f6c2d",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "123",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                        {
-                            "id": "456",
-                            "name": "pyproject.toml",
-                            "isMain": False,
-                            "fileType": "1",
-                            "isEntryPoint": False,
-                            "ignoredFromPublish": False,
-                        },
-                        {
-                            "id": "789",
-                            "name": "uipath.json",
-                            "isMain": False,
-                            "fileType": "1",
-                            "isEntryPoint": False,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                }
-            ],
+            "folders": [],
             "files": [
+                {
+                    "id": "123",
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
+                {
+                    "id": "456",
+                    "name": "pyproject.toml",
+                    "isMain": False,
+                    "fileType": "1",
+                    "isEntryPoint": False,
+                    "ignoredFromPublish": False,
+                },
+                {
+                    "id": "789",
+                    "name": "uipath.json",
+                    "isMain": False,
+                    "fileType": "1",
+                    "isEntryPoint": False,
+                    "ignoredFromPublish": False,
+                },
                 {
                     "id": "246",
                     "name": "agent.json",
@@ -206,11 +199,6 @@ class TestPush:
             json=mock_structure,
         )
 
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
-
         self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         # Mock file downloads for conflict detection
@@ -335,25 +323,13 @@ class TestPush:
             "files": [],
             "folderType": "0",
         }
-        # Create source_code folder
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
-            status_code=200,
-            json={
-                "id": "123",
-                "name": "source_code",
-                "folders": [],
-                "files": [],
-            },
-        )
 
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
 
-        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         httpx_mock.add_response(
             method="POST",
@@ -367,10 +343,6 @@ class TestPush:
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             # Create necessary files
@@ -482,31 +454,25 @@ class TestPush:
         mock_structure = {
             "id": "root",
             "name": "root",
-            "folders": [
+            "folders": [],
+            "files": [
                 {
                     "id": "123",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "123",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                        {
-                            "id": "789",
-                            "name": "uipath.json",
-                            "isMain": False,
-                            "fileType": "1",
-                            "isEntryPoint": False,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                }
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
+                {
+                    "id": "789",
+                    "name": "uipath.json",
+                    "isMain": False,
+                    "fileType": "1",
+                    "isEntryPoint": False,
+                    "ignoredFromPublish": False,
+                },
             ],
-            "files": [],
             "folderType": "0",
         }
 
@@ -546,10 +512,6 @@ class TestPush:
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             # Create necessary files
@@ -613,25 +575,12 @@ class TestPush:
             "folderType": "0",
         }
 
-        # Create source_code folder
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
-            status_code=200,
-            json={
-                "id": "123",
-                "name": "source_code",
-                "folders": [],
-                "files": [],
-            },
-        )
-
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
 
-        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         httpx_mock.add_response(
             method="POST",
@@ -645,10 +594,6 @@ class TestPush:
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
@@ -702,25 +647,12 @@ class TestPush:
             "folderType": "0",
         }
 
-        # Create source_code folder
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
-            status_code=200,
-            json={
-                "id": "123",
-                "name": "source_code",
-                "folders": [],
-                "files": [],
-            },
-        )
-
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
 
-        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         httpx_mock.add_response(
             method="POST",
@@ -734,10 +666,6 @@ class TestPush:
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
@@ -787,19 +715,12 @@ class TestPush:
             "folderType": "0",
         }
 
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
-            status_code=200,
-            json={"id": "123", "name": "source_code", "folders": [], "files": []},
-        )
-
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
 
-        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         httpx_mock.add_response(
             method="POST",
@@ -808,10 +729,6 @@ class TestPush:
             json={"success": True},
         )
 
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
@@ -891,19 +808,12 @@ class TestPush:
             "folderType": "0",
         }
 
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
-            status_code=200,
-            json={"id": "123", "name": "source_code", "folders": [], "files": []},
-        )
-
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
 
-        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         httpx_mock.add_response(
             method="POST",
@@ -912,10 +822,6 @@ class TestPush:
             json={"success": True},
         )
 
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
@@ -997,19 +903,12 @@ class TestPush:
             "folderType": "0",
         }
 
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
-            status_code=200,
-            json={"id": "123", "name": "source_code", "folders": [], "files": []},
-        )
-
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
         )
 
-        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
         httpx_mock.add_response(
             method="POST",
@@ -1018,10 +917,6 @@ class TestPush:
             json={"success": True},
         )
 
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
         httpx_mock.add_response(
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
             json=mock_structure,
@@ -1095,23 +990,17 @@ class TestPush:
         mock_structure = {
             "id": "root",
             "name": "root",
-            "folders": [
+            "folders": [],
+            "files": [
                 {
-                    "id": "123",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "456",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                }
+                    "id": "456",
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
             ],
-            "files": [],
             "folderType": "0",
         }
 
@@ -1145,12 +1034,6 @@ class TestPush:
             json={"success": True},
         )
 
-        # Mock empty folder cleanup
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
-
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
                 f.write(uipath_json.to_json())
@@ -1185,23 +1068,17 @@ class TestPush:
         mock_structure = {
             "id": "root",
             "name": "root",
-            "folders": [
+            "folders": [],
+            "files": [
                 {
-                    "id": "123",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "456",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                }
+                    "id": "456",
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
             ],
-            "files": [],
             "folderType": "0",
         }
 
@@ -1235,12 +1112,6 @@ class TestPush:
             json={"success": True},
         )
 
-        # Mock empty folder cleanup
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
-
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
                 f.write(uipath_json.to_json())
@@ -1276,31 +1147,25 @@ class TestPush:
         mock_structure = {
             "id": "root",
             "name": "root",
-            "folders": [
+            "folders": [],
+            "files": [
                 {
-                    "id": "123",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "456",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                        {
-                            "id": "789",
-                            "name": "helper.py",
-                            "isMain": False,
-                            "fileType": "1",
-                            "isEntryPoint": False,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                }
+                    "id": "456",
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
+                {
+                    "id": "789",
+                    "name": "helper.py",
+                    "isMain": False,
+                    "fileType": "1",
+                    "isEntryPoint": False,
+                    "ignoredFromPublish": False,
+                },
             ],
-            "files": [],
             "folderType": "0",
         }
 
@@ -1341,12 +1206,6 @@ class TestPush:
             json={"success": True},
         )
 
-        # Mock empty folder cleanup
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
-
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
                 f.write(uipath_json.to_json())
@@ -1386,31 +1245,25 @@ class TestPush:
         mock_structure = {
             "id": "root",
             "name": "root",
-            "folders": [
+            "folders": [],
+            "files": [
                 {
-                    "id": "123",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "456",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                        {
-                            "id": "789",
-                            "name": "helper.py",
-                            "isMain": False,
-                            "fileType": "1",
-                            "isEntryPoint": False,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                }
+                    "id": "456",
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
+                {
+                    "id": "789",
+                    "name": "helper.py",
+                    "isMain": False,
+                    "fileType": "1",
+                    "isEntryPoint": False,
+                    "ignoredFromPublish": False,
+                },
             ],
-            "files": [],
             "folderType": "0",
         }
 
@@ -1448,12 +1301,6 @@ class TestPush:
             json={"success": True},
         )
 
-        # Mock empty folder cleanup
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
-
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
                 f.write(uipath_json.to_json())
@@ -1485,32 +1332,18 @@ class TestPush:
         mock_env_vars: Dict[str, str],
         httpx_mock: HTTPXMock,
     ) -> None:
-        """Test that remote coded-evals files are not deleted when no local evals folder exists."""
+        """Test that remote evaluations files are not deleted when no local evals folder exists."""
         base_url = "https://cloud.uipath.com/organization"
         project_id = "test-project-id"
 
-        # Mock the project structure with existing coded-evals folder and files
+        # Mock the project structure with existing evaluations folder and files
         mock_structure = {
             "id": "root",
             "name": "root",
             "folders": [
                 {
-                    "id": "source-code-123",
-                    "name": "source_code",
-                    "files": [
-                        {
-                            "id": "main-456",
-                            "name": "main.py",
-                            "isMain": True,
-                            "fileType": "1",
-                            "isEntryPoint": True,
-                            "ignoredFromPublish": False,
-                        },
-                    ],
-                },
-                {
-                    "id": "coded-evals-folder-id",
-                    "name": "coded-evals",
+                    "id": "evaluations-folder-id",
+                    "name": "evaluations",
                     "folders": [
                         {
                             "id": "evaluators-folder-id",
@@ -1546,7 +1379,16 @@ class TestPush:
                     "files": [],
                 },
             ],
-            "files": [],
+            "files": [
+                {
+                    "id": "main-456",
+                    "name": "main.py",
+                    "isMain": True,
+                    "fileType": "1",
+                    "isEntryPoint": True,
+                    "ignoredFromPublish": False,
+                },
+            ],
             "folderType": "0",
         }
 
@@ -1577,12 +1419,6 @@ class TestPush:
             json={"success": True},
         )
 
-        # Mock empty folder cleanup
-        httpx_mock.add_response(
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
-            json=mock_structure,
-        )
-
         with runner.isolated_filesystem(temp_dir=temp_dir):
             with open("uipath.json", "w") as f:
                 f.write(uipath_json.to_json())
@@ -1599,11 +1435,11 @@ class TestPush:
             result = runner.invoke(cli, ["push", "./"])
             assert result.exit_code == 0
 
-            # Verify that no deletion messages appear for coded-evals files
+            # Verify that no deletion messages appear for evaluations files
             assert (
-                "Deleting coded-evals/evaluators/evaluator-1.json" not in result.output
+                "Deleting evaluations/evaluators/evaluator-1.json" not in result.output
             )
-            assert "Deleting coded-evals/eval-sets/eval-set-1.json" not in result.output
+            assert "Deleting evaluations/eval-sets/eval-set-1.json" not in result.output
 
             # Get the StructuralMigration request to verify no deletions were sent
             structural_migration_request = httpx_mock.get_request(
@@ -1613,7 +1449,7 @@ class TestPush:
             assert structural_migration_request is not None
 
             # Parse the multipart form data to check deleted_resources
-            # The deleted_resources should not include the coded-evals files
+            # The deleted_resources should not include the evaluations files
             content = structural_migration_request.content
 
             # Check that the deleted resource IDs are not present in the request
